@@ -42,7 +42,7 @@ fhir_resource_type(string = "medicationstatement") #fixed
 fhir_resource_type(string = "medicationstatement", fix_capitalization = FALSE) #not fixed
 
 fhir_resource_type(string = "Hospital") #an unknown resource type, a warning is issued
-# Warnmeldung:
+# Warning:
 # In fhir_resource_type("Hospital") :
 #   You gave "Hospital" as the resource type.
 # This doesn't match any of the resource types defined under
@@ -267,13 +267,108 @@ fhir_save(bundles = patient_bundles, directory = temp_dir)
 ## -----------------------------------------------------------------------------
 bundles <- fhir_load(directory = temp_dir)
 
+## ---- eval=FALSE--------------------------------------------------------------
+#  request <- fhir_url(url = "http://hapi.fhir.org/baseR4",
+#  					resource = "Patient",
+#  					parameters = c("_elements" = "name,gender,birthDate",
+#  								   "_count"= "2"))
+#  
+#  
+#  bundles <- fhir_search(request, max_bundles = 1)
+#  
+#  cat(toString(bundles[[1]]))
+
+## -----------------------------------------------------------------------------
+# <Bundle>
+#   <id value="8e0db3ce-817b-48cd-ba3e-1a0d20f64366"/>
+#   <meta>
+#     <lastUpdated value="2022-03-31T08:48:55.934+00:00"/>
+#   </meta>
+#   <type value="searchset"/>
+#   <link>
+#     <relation value="self"/>
+#     <url value="http://hapi.fhir.org/baseR4/Patient?_count=2&amp;_elements=name%2Cgender%2CbirthDate"/>
+#   </link>
+#   <link>
+#     <relation value="next"/>
+#     <url value="http://hapi.fhir.org/baseR4?_getpages=8e0db3ce-817b-48cd-ba3e-1a0d20f64366&amp;_getpagesoffset=2&amp;_count=2&amp;_pretty=true&amp;_bundletype=searchset&amp;_elements=birthDate,gender,name"/>
+#   </link>
+#   <entry>
+#     <fullUrl value="http://hapi.fhir.org/baseR4/Patient/2564886"/>
+#     <resource>
+#       <Patient>
+#         <id value="2564886"/>
+#         <meta>
+#           <versionId value="1"/>
+#           <lastUpdated value="2021-09-28T01:04:35.774+00:00"/>
+#           <source value="#rxRuwftRVG3erMwy"/>
+#           <tag>
+#             <system value="http://terminology.hl7.org/CodeSystem/v3-ObservationValue"/>
+#             <code value="SUBSETTED"/>
+#             <display value="Resource encoded in summary mode"/>
+#           </tag>
+#         </meta>
+#         <name>
+#           <text value="반영훈 사원"/>
+#           <family value="반"/>
+#           <given value="영훈"/>
+#           <prefix value="사원"/>
+#         </name>
+#         <gender value="male"/>
+#         <birthDate value="1992-01-12"/>
+#       </Patient>
+#     </resource>
+#     <search>
+#       <mode value="match"/>
+#     </search>
+#   </entry>
+#   <entry>
+#     <fullUrl value="http://hapi.fhir.org/baseR4/Patient/2564911"/>
+#     <resource>
+#       <Patient>
+#         <id value="2564911"/>
+#         <meta>
+#           <versionId value="1"/>
+#           <lastUpdated value="2021-09-28T01:12:59.207+00:00"/>
+#           <source value="#rmWF4JDz6p1WVwzl"/>
+#           <security>
+#             <system value="http://terminology.hl7.org/CodeSystem/v2-0203"/>
+#             <code value="RM"/>
+#           </security>
+#           <tag>
+#             <system value="http://terminology.hl7.org/CodeSystem/v2-0203sbtest05"/>
+#             <code value="SBTest05m"/>
+#           </tag>
+#           <tag>
+#             <system value="http://terminology.hl7.org/CodeSystem/v3-ObservationValue"/>
+#             <code value="SUBSETTED"/>
+#             <display value="Resource encoded in summary mode"/>
+#           </tag>
+#         </meta>
+#         <name>
+#           <use value="usual"/>
+#           <text value="human name"/>
+#           <family value="Jonathan"/>
+#           <given value="token_sort_test_data05"/>
+#         </name>
+#         <gender value="male"/>
+#         <birthDate value="2021-09-01"/>
+#       </Patient>
+#     </resource>
+#     <search>
+#       <mode value="match"/>
+#     </search>
+#   </entry>
+# </Bundle>
+
 ## ---- eval=F------------------------------------------------------------------
 #  request <- fhir_url(url = "http://hapi.fhir.org/baseR4", resource = "Patient")
 #  
 #  fhir_search(
 #  	request      = request,
 #  	max_bundles  = 10,
-#  	save_to_disc = "MyProject/downloadedBundles")
+#  	save_to_disc = "MyProject/downloadedBundles"
+#  	)
 #  
 #  bundles<- fhir_load(directory = "MyProject/downloadedBundles")
 
@@ -291,7 +386,7 @@ strsplit(fhir_next_bundle_url(), "&")
 #  	resource   = "Observation",
 #  	parameters = list("_count" = "500"))
 #  
-#  #count <- 0
+#  count <- 0
 #  
 #  table_description <- fhir_table_description(resource = "Observation")
 #  
@@ -309,11 +404,93 @@ strsplit(fhir_next_bundle_url(), "&")
 #  	#retrieve starting point for next 10 bundles
 #  	url <- fhir_next_bundle_url()
 #  	
-#  	# count <- count + 1
+#  	count <- count + 1
 #  	# if(count >= 20) {break}
 #  }
 #  
 
+## ---- eval = FALSE------------------------------------------------------------
+#  # define list of Patient resource ids
+#  ids <- c("4b7736c3-c005-4383-bf7c-99710811efd9", "bef39d3a-62bb-48c0-83ff-3bb70b51d831",
+#  		 "f371ed2f-5cb0-4093-a491-9df6e6bfcdf2", "277c4631-955e-4b52-bd40-78ddcde333b1",
+#  		 "72173a13-d32f-4489-a7b4-dfc301df087f", "4a97acec-028e-4b45-a72f-2b7e08cf80ba")
+#  
+#  #split into smaller chunks of 2
+#  id_list <- split(ids, ceiling(seq_along(ids)/2))
+#  
+#  #Define function that downloads one chunk of patients and serializes the result
+#  extract_and_serialize <- function(x){
+#                              b <- fhir_get_resources_by_ids(base_url = "http://hapi.fhir.org/baseR4",
+#                                                             resource = "Patient",
+#                                                             ids = x)
+#                              fhir_serialize(b)
+#  }
+#  
+#  #Download using 2 cores on linux:
+#  bundles_serialized <- parallel::mclapply(
+#  	X = pat_list,
+#  	FUN = extract_and_serialize,
+#      mc.cores = 2
+#  )
+#  
+#  #Unserialize the resulting list and create one fhir_bundle_list object from it
+#  bundles_unserialized <- lapply(bundles_serialized, fhir_unserialize)
+#  result <- fhir_bundle_list(unlist(bundles_unserialized, recursive = FALSE))
+#  
+
+## ---- eval=FALSE--------------------------------------------------------------
+#  #Download all Encounters
+#  encounter_bundles <- fhir_search(request = "http://hapi.fhir.org/baseR4/Encounter")
+#  
+#  #Flatten
+#  encounter_table <- fhir_crack(
+#  	bundles = encounter_bundles,
+#  	design = fhir_table_description(resource = "Encounter")
+#  )
+#  
+#  #Extract Patient ids
+#  pat_ids <- sub("Patient/", "", encounter_table$subject.reference)
+#  
+#  #Split into chunks of 20
+#  pat_id_list <- split(pat_ids, ceiling(seq_along(pat_ids)/20))
+#  
+#  #Define function that downloads one chunk and serializes the result
+#  extract_and_serialize <- function(x){
+#                              b <- fhir_get_resources_by_ids(base_url = "http://hapi.fhir.org/baseR4",
+#                              							   resource = "Patient",
+#                                                             ids = x)
+#                              fhir_serialize(b)
+#  }
+#  
+#  #Download using 4 cores on linux:
+#  bundles_serialized <- parallel::mclapply(
+#  	X = pat_id_list,
+#  	FUN = extract_and_serialize,
+#      mc.cores = 4
+#  )
+#  
+#  #Unserialize the resulting list and create one fhir_bundle_list object from it
+#  bundles_unserialized <- lapply(bundles_serialized, fhir_unserialize)
+#  result <- fhir_bundle_list(unlist(bundles_unserialized, recursive = FALSE))
+#  
+
 ## ---- eval=F------------------------------------------------------------------
-#  cap <- fhir_capability_statement(url = "http://hapi.fhir.org/baseR4", verbose = 0)
+#  bundle <- fhir_sample_resources(
+#  	base_url    = "http://hapi.fhir.org/baseR4",
+#  	resource    = "Patient",
+#  	parameters  = c(gender = "female", birthdate = "lt1960-01-01"),
+#  	sample_size = 10
+#  )
+
+## ---- include=F---------------------------------------------------------------
+bundle <- fhir_unserialize(fhircrackr:::female_pat_bundle)
+
+## -----------------------------------------------------------------------------
+pat <- fhir_table_description(resource = "Patient",
+							  cols = c("id", "gender", "birthDate"))
+
+fhir_crack(bundles = bundle, design = pat)
+
+## ---- eval=F------------------------------------------------------------------
+#  cap <- fhir_capability_statement(url = "http://hapi.fhir.org/baseR4")
 
